#ifndef LEVELREADER_H
#define LEVELREADER_H

#include <list>
#include <string>

#include "Exception.h"


//----------------------------------------------------------------------------
class LevelReader
{
    typedef std::list<std::string> Levels;

  public:
    typedef Levels::iterator iterator;
    typedef Levels::const_iterator const_iterator;

    //------------------------------------------------------------------------
    LevelReader();
    ~LevelReader();

    //------------------------------------------------------------------------
    void init(const char *mission) throw (Exception);

    //------------------------------------------------------------------------
    inline const std::string &getMission() const
    {
        return m_mission;
    }

    //------------------------------------------------------------------------
    inline bool empty() const { return m_levels.empty(); }
    inline size_t size() const { return m_levels.size(); }

    iterator begin() { return m_levels.begin(); }
    iterator end() { return m_levels.end(); }

    const_iterator begin() const { return m_levels.begin(); }
    const_iterator end() const { return m_levels.end(); }

  private:
    //------------------------------------------------------------------------
    std::string m_mission;
    Levels m_levels;
};


//----------------------------------------------------------------------------
class MissionReader
{
    //------------------------------------------------------------------------
    typedef std::pair<std::string, std::string> Entry;
    typedef std::list<Entry> Missions;

  public:
    typedef Missions::iterator iterator;
    typedef Missions::const_iterator const_iterator;

    //------------------------------------------------------------------------
    MissionReader() throw (Exception);
    ~MissionReader();

    //------------------------------------------------------------------------
    void init()
        throw (Exception);

    //------------------------------------------------------------------------
    inline bool empty() const { return m_missions.empty(); }
    inline size_t size() const { return m_missions.size(); }

    iterator begin() { return m_missions.begin(); }
    iterator end() { return m_missions.end(); }

    const_iterator begin() const { return m_missions.begin(); }
    const_iterator end() const { return m_missions.end(); }

  private:
    Missions m_missions;
};

#endif //LEVELREADER_H
