#ifndef MATHTOOLS_H
#define MATHTOOLS_H

#include <cmath>

//----------------------------------------------------------------------------
/**
 * This namespace contains some common needed functions
 * related to mathematical and geometric operations.
 */
namespace MATH_TOOLS
{
    //------------------------------------------------------------------------
    /**
     * Returns the angle between (0,0)(x,y) and the y axis,
     * counted in clockwise order and inside the value range from [0..360).
     */
    double getAngle(double x, double y);

    /**
     * Returns the angle between (x1,y1)(x2,y2) and the y axis,
     * counted in clockwise order and inside the value range from [0..360).
     */
    inline double getAngle(double x1, double y1, double x2, double y2)
    {
        return getAngle(x2-x1, y2-y1);
    }

    inline int getAngle(int x, int y)
    {
        return (int)rint(getAngle(1.0*x, 1.0*y));
    }

    inline int getAngle(int x1, int y1, int x2, int y2)
    {
        return getAngle(x2-x1, y2-y1);
    }

    //------------------------------------------------------------------------
    /**
     * Converts the given metric angle to a display angle
     */
    int convertAngle(int angle);
}

#endif //MATHTOOLS_H
