#ifndef CRATES_H
#define CRATES_H

#include "Tools.h"
#include "StaticDecorationBase.h"

//----------------------------------------------------------------------------
class CrateSurfaces : public SurfacesBase
{
    SURFACES_SINGLETON_OBJECT(CrateSurfaces);

  public:

    enum Size
    {
        S_SMALL = 0,
        S_MEDIUM = 1,
        S_BIG = 2,
        S_TOTAL_NUMBER = 3
    };

    inline const SDL_Surface *getSurface(Size size) const
    {
        assert(size >= 0);
        assert(size < S_TOTAL_NUMBER);

        return m_crates[size];
    }

  private:

    /// All crate surfaces.
    SDL_Surface *m_crates[S_TOTAL_NUMBER];
};



//----------------------------------------------------------------------------
class Crate : public StaticDecorationBase
{
  public:
    class InitializationData : public StaticDecorationBase::InitializationData
    {
      public:
        InitializationData(const XMLNode *crateNode)
            throw (XMLException);
        ~InitializationData();

        CrateSurfaces::Size size;
    };


    virtual ~Crate();

    static Crate *create(const XMLNode *crateNode)
        throw (Exception);

    inline CrateSurfaces::Size getSize() const 
    {
        return m_size;
    }

    inline unsigned getMass() const
    {
        return (m_size+1)*20;
    }
    
  protected:
    Crate(const InitializationData &init);

  private:
    void do_update();

    //------------------------------------------------------------------------
    DECLARE_VISITOR_API();

    CrateSurfaces::Size m_size;
};

#endif //CRATES_H
