#ifndef MOVINGDECORATIONBASE_H
#define MOVINGDECORATIONBASE_H

#include "DecorationBase.h"

//----------------------------------------------------------------------------
/**
 * This is a base class for all moving decorations.
 */
class MovingDecorationBase : public DecorationBase
{
  public:
    //------------------------------------------------------------------------
    class InitializationData
    {
      public:
        InitializationData(const XMLNode *node)
            throw (XMLException);
        virtual ~InitializationData();
    };

    //------------------------------------------------------------------------
    virtual ~MovingDecorationBase();


    //------------------------------------------------------------------------
    inline void setPosition(Sint16 x, Sint16 y)
    {
        m_fineXPosition = 1.0 * x;
        m_fineYPosition = 1.0 * y;
        ObjectBase::setPosition(x, y);
    }

    //------------------------------------------------------------------------
    inline void incFinePosition(double xInc, double yInc)
    {
        m_fineXPosition += xInc;
        m_fineYPosition += yInc;
    }

    //------------------------------------------------------------------------
    inline void updatePosition()
    {
        ObjectBase::setPosition((Sint16)rint(m_fineXPosition),
                                (Sint16)rint(m_fineYPosition));
    }

    //------------------------------------------------------------------------
    inline void setFineVelocity(double x, double y)
    {
        m_fineXVelocity = x;
        m_fineYVelocity = y;
    }

    inline double getFineXVelocity() const
    {
        return m_fineXVelocity;
    }

    inline double getFineYVelocity() const
    {
        return m_fineYVelocity;
    }

    //------------------------------------------------------------------------
    /**
     * This update() implementation will call do_update().
     * The decoration's position before and after the do_update() call
     * will be merged and stored in updateRect.
     *
     * @param updateRect The update rectangle.
     */
    void update(SDL_Rect &updateRect);

  protected:
    //------------------------------------------------------------------------
    MovingDecorationBase(const InitializationData &init);

  private:
    /// Called by update() to do the actual updating of the decoration.
    virtual void do_update() = 0;

    //------------------------------------------------------------------------
    double m_fineXPosition;
    double m_fineYPosition;

    double m_fineXVelocity;
    double m_fineYVelocity;
};

#endif //MOVINGDECORATIONBASE_H
